@@ -82,11 +82,66 @@ class _HEJIAccidental(object):
 
 
 class MutwoPitchToHEJIAbjadPitchConverter(MutwoPitchToAbjadPitchConverter):
-    """Convert Mutwo :obj:`~mutwo.parameters.pitches.JustIntonationPitch` objects to Abjad Pitch objects."""
+    """Convert Mutwo :obj:`~mutwo.parameters.pitches.JustIntonationPitch` objects to Abjad Pitch objects.
+
+    :param reference_pitch: The reference pitch (1/1). Should be a diatonic
+        pitch name (see
+        :const:`~mutwo.parameters.pitches_constants.ASCENDING_DIATONIC_PITCH_NAMES`)
+        in English nomenclature. For any other reference pitch than 'c', Lilyponds
+        midi rendering for pitches with the diatonic pitch 'c' will be slightly
+        out of tune (because the first value of :arg:`global_scale`
+        always have to be 0).
+    :type reference_pitch: str, optional
+    :param prime_to_heji_accidental_name: Mapping of a prime number
+        to a string which indicates the respective prime number in the resulting
+        accidental name. See
+        :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_PRIME_TO_HEJI_ACCIDENTAL_NAME`
+        for the default mapping.
+    :type prime_to_heji_accidental_name: typing.Dict[int, str], optional
+    :param otonality_indicator: String which indicates that the
+        respective prime alteration is otonal. See
+        :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_OTONALITY_INDICATOR`
+        for the default value.
+    :type otonality_indicator: str, optional
+    :param utonality_indicator: String which indicates that the
+        respective prime alteration is utonal. See
+        :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_OTONALITY_INDICATOR`
+        for the default value.
+    :type utonality_indicator: str, optional
+    :param exponent_to_exponent_indicator: Function to convert the
+        exponent of a prime number to string which indicates the respective
+        exponent. See
+        :func:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_EXPONENT_TO_EXPONENT_INDICATOR`
+        for the default function.
+    :type exponent_to_exponent_indicator: typing.Callable[[int], str], optional
+    :param tempered_pitch_indicator: String which indicates that the
+        respective accidental is tempered (12 EDO). See
+        :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_TEMPERED_PITCH_INDICATOR`
+        for the default value.
+    :type tempered_pitch_indicator: str, optional
+
+    The resulting Abjad pitches are expected to be used in combination with tuning
+    files that are generated by
+    :class:`~mutwo.converters.frontends.ekmelily.HEJIEkmelilyTuningFileConverter`
+    and with the Lilypond extension
+    `Ekmelily <http://www.ekmelic-music.org/en/extra/ekmelily.htm>`_.
+    You can find pre-generated tuning files
+    `here <https://github.com/levinericzimmermann/ekme-heji.ily>`_.
+
+    >>> from mutwo.parameters import pitches
+    >>> from mutwo.converters.frontends import abjad
+    >>> my_ji_pitch = pitches.JustIntonationPitch('5/4')
+    >>> converter_on_a = abjad.MutwoPitchToHEJIAbjadPitchConverter(reference_pitch='a')
+    >>> converter_on_c = abjad.MutwoPitchToHEJIAbjadPitchConverter(reference_pitch='c')
+    >>> converter_on_a.convert(my_ji_pitch)
+    NamedPitch("csoaa''")
+    >>> converter_on_c.convert(my_ji_pitch)
+    NamedPitch("eoaa'")
+    """
 
     def __init__(
         self,
-        reference: str = "a",
+        reference_pitch: str = "a",
         prime_to_heji_accidental_name: typing.Optional[typing.Dict[int, str]] = None,
         otonality_indicator: str = None,
         utonality_indicator: str = None,
@@ -115,23 +170,22 @@ class MutwoPitchToHEJIAbjadPitchConverter(MutwoPitchToAbjadPitchConverter):
                 ekmelily_constants.DEFAULT_TEMPERED_PITCH_INDICATOR
             )
 
-        self._reference = reference
+        self._reference_pitch = reference_pitch
         self._otonality_indicator = otonality_indicator
         self._utonality_indicator = utonality_indicator
         self._exponent_to_exponent_indicator = exponent_to_exponent_indicator
         self._tempered_pitch_indicator = tempered_pitch_indicator
         self._reference_index = parameters.pitches_constants.ASCENDING_DIATONIC_PITCH_NAMES.index(
-            reference
+            reference_pitch
         )
         self._prime_to_heji_accidental_name = prime_to_heji_accidental_name
 
     def _convert_just_intonation_pitch(
-        self,
-        pitch_to_convert: parameters.pitches.JustIntonationPitch,
+        self, pitch_to_convert: parameters.pitches.JustIntonationPitch,
     ) -> abjad.Pitch:
         # find pythagorean pitch
         closest_pythagorean_pitch_name = pitch_to_convert.get_closest_pythagorean_pitch_name(
-            self._reference
+            self._reference_pitch
         )
         abjad_pitch_class = abjad.NamedPitchClass(closest_pythagorean_pitch_name)
 
