@@ -14,6 +14,7 @@ _abjad_attachment_class_name_to_class = {
     for cls_name, cls in inspect.getmembers(abjad_attachments, inspect.isclass)
     if not inspect.isabstract(cls)
 }
+
 PLAYING_INDICATOR_TO_ABJAD_ATTACHMENT = {
     playing_indicator_name: _abjad_attachment_class_name_to_class[
         playing_indicator_name
@@ -21,6 +22,8 @@ PLAYING_INDICATOR_TO_ABJAD_ATTACHMENT = {
     for playing_indicator_name in playing_indicators.PlayingIndicatorCollection.__dataclass_fields__.keys()  # type: ignore
     if playing_indicator_name in _abjad_attachment_class_name_to_class
 }
+"""Mapping of playingindicator to Abjad attachment."""
+
 NOTATION_INDICATOR_TO_ABJAD_ATTACHMENT = {
     notation_indicator_name: _abjad_attachment_class_name_to_class[
         notation_indicator_name
@@ -28,6 +31,9 @@ NOTATION_INDICATOR_TO_ABJAD_ATTACHMENT = {
     for notation_indicator_name in notation_indicators.NotationIndicatorCollection.__dataclass_fields__.keys()  # type: ignore
     if notation_indicator_name in _abjad_attachment_class_name_to_class
 }
+"""Mapping of notation indicator to Abjad attachment."""
+
 AVAILABLE_ABJAD_ATTACHMENTS = _abjad_attachment_class_name_to_class.keys()
+"""All available Abjad attachments."""
 
 del _abjad_attachment_class_name_to_class
