@@ -7,8 +7,7 @@ to build tuning files to be used with the 'ekmel-main.ily' script from Thomas Ri
 
 **Disclaimer:**
 
-For now the converters of this file only support making notation tables for
-English note names.
+For now the converters only support making notation tables for English note names.
 """
 
 import dataclasses
@@ -63,12 +62,11 @@ class EkmelilyAccidental(object):
     **Example:**
 
     >>> from mutwo.converter.frontends import ekmelily
+    >>> natural = ekmelily.EkmelilyAccidental('', ("#xE261",), 0)
     >>> sharp = ekmelily.EkmelilyAccidental('s', ("#xE262",), 100)
     >>> flat = ekmelily.EkmelilyAccidental('f', ("#xE260",), -100)
     """
 
-    # TODO(add possibility to declare different languages)
-    # typing.Union[str, typing.Dict[str, str]]
     accidental_name: str
     accidental_glyphs: typing.Tuple[str, ...]
     deviation_in_cents: float
@@ -104,12 +102,13 @@ class EkmelilyTuningFileConverter(converters_abc.Converter):
     **Example:**
 
     >>> from mutwo.converter.frontends import ekmelily
+    >>> natural = ekmelily.EkmelilyAccidental('', ("#xE261",), 0)
     >>> sharp = ekmelily.EkmelilyAccidental('s', ("#xE262",), 100)
     >>> flat = ekmelily.EkmelilyAccidental('f', ("#xE260",), -100)
     >>> eigth_tone_sharp = ekmelily.EkmelilyAccidental('es', ("#xE2C7",), 25)
     >>> eigth_tone_flat = ekmelily.EkmelilyAccidental('ef', ("#xE2C2",), -25)
     >>> converter = ekmelily.EkmelilyTuningFileConverter(
-    >>>     'ekme-test.ily', (sharp, flat, eigth_tone_sharp, eigth_tone_flat)
+    >>>     'ekme-test.ily', (natural, sharp, flat, eigth_tone_sharp, eigth_tone_flat)
     >>> )
     >>> converter.convert()
     """
@@ -181,6 +180,25 @@ class EkmelilyTuningFileConverter(converters_abc.Converter):
         # readable by Lilypond
         return "#x{}".format(str(hex(accidental_index))[2:].upper())
 
+    @staticmethod
+    def _find_and_group_accidentals_by_specific_deviation_in_cents(
+        ekmelily_accidentals: typing.Sequence[EkmelilyAccidental],
+        deviation_in_cents: float,
+    ) -> typing.Tuple[
+        typing.Tuple[EkmelilyAccidental, ...], typing.Tuple[EkmelilyAccidental, ...]
+    ]:
+        positive, negative = [], []
+        for accidental in ekmelily_accidentals:
+            if accidental.deviation_in_cents == deviation_in_cents:
+                positive.append(accidental)
+            elif (
+                accidental.deviation_in_cents == -deviation_in_cents
+                and deviation_in_cents != 0
+            ):
+                negative.append(accidental)
+
+        return tuple(positive), tuple(negative)
+
     @staticmethod
     def _group_accidentals_by_deviations_in_cents(
         ekmelily_accidentals: typing.Sequence[EkmelilyAccidental],
@@ -207,13 +225,8 @@ class EkmelilyTuningFileConverter(converters_abc.Converter):
         accidentals_grouped_by_deviations_in_cents = tuple(
             (
                 deviation_in_cents,
-                tuple(
-                    tuple(
-                        accidental
-                        for accidental in ekmelily_accidentals
-                        if value * accidental.deviation_in_cents == deviation_in_cents
-                    )
-                    for value in (1, -1)
+                EkmelilyTuningFileConverter._find_and_group_accidentals_by_specific_deviation_in_cents(
+                    ekmelily_accidentals, deviation_in_cents
                 ),
             )
             for deviation_in_cents in available_deviations_in_cents
@@ -232,17 +245,9 @@ class EkmelilyTuningFileConverter(converters_abc.Converter):
         is_positive: bool,
         absolute_deviation_in_cents: float,
     ):
-        # special treatment for accidental with cent deviation 0
-        # -> this is always alteration_code '#x00' and get implicitly
-        #    defined if the user doesn't override it
-        if absolute_deviation_in_cents == 0:
-            alteration_code = EkmelilyTuningFileConverter._accidental_index_to_alteration_code(
-                int(not is_positive)
-            )
-        else:
-            alteration_code = EkmelilyTuningFileConverter._accidental_index_to_alteration_code(
-                accidental_index
-            )
+        alteration_code = EkmelilyTuningFileConverter._accidental_index_to_alteration_code(
+            accidental_index
+        )
 
         if accidental:
             accidental_to_alteration_code_mapping.update({accidental: alteration_code})
@@ -349,8 +354,7 @@ class EkmelilyTuningFileConverter(converters_abc.Converter):
             str, fractions.Fraction
         ] = {}
 
-        # start with hex x12 like in ekmel.ily
-        nth_alteration = 18
+        nth_alteration = 0
         for (
             absolute_deviation_in_cents,
             accidental_group,
@@ -408,19 +412,8 @@ class EkmelilyTuningFileConverter(converters_abc.Converter):
         return None
 
     def _make_languages_table(self) -> str:
-        # TODO(support more languages than English)
         language_table_entries = []
 
-        # 1. Append pitches without accidentals
-        for nth_diatonic_pitch, diatonic_pitch in enumerate(
-            pitches_constants.ASCENDING_DIATONIC_PITCH_NAMES
-        ):
-            natural_pitch_entry = "({} {} . 0)".format(
-                diatonic_pitch, nth_diatonic_pitch
-            )
-            language_table_entries.append(natural_pitch_entry)
-
-        # 2. Append pitches with accidentals
         for accidental in self._ekmelily_accidentals:
             for nth_diatonic_pitch, diatonic_pitch in enumerate(
                 pitches_constants.ASCENDING_DIATONIC_PITCH_NAMES
@@ -437,45 +430,9 @@ class EkmelilyTuningFileConverter(converters_abc.Converter):
         )
         return languages_table
 
-    def _add_natural_alteration(
-        self, notations_table_entries: typing.List[str]
-    ) -> None:
-        natural_alteration_code = EkmelilyTuningFileConverter._accidental_index_to_alteration_code(
-            0
-        )
-        if (
-            natural_alteration_code
-            not in self._accidental_to_alteration_code_mapping.values()
-        ):
-            natural_alteration_entry = "({} {})".format(
-                natural_alteration_code,
-                frontends.ekmelily_constants.PRIME_AND_EXPONENT_AND_TRADITIONAL_ACCIDENTAL_TO_ACCIDENTAL_GLYPH[
-                    (
-                        None,
-                        None,
-                        pitches_constants.PITCH_CLASS_MODIFICATION_TO_ACCIDENTAL_NAME[
-                            fractions.Fraction(0, 1)
-                        ],
-                    )
-                ],
-            )
-            notations_table_entries.append(natural_alteration_entry)
-            message = (
-                "No EkmelilyAccidental with cents_deviation = 0 has been found."
-                " Therefore mutwo automatically added natural sign with glyph '#xE261'"
-                " for natural pitches."
-            )
-            warnings.warn(message)
-
     def _make_notations_table(self) -> str:
-        # add natural accidental for diatonic pitches without alterations
         notations_table_entries: typing.List[str] = []
 
-        # add glyph for natural if it hasn't been defined in ekmelily_accidentals
-        # argument of __init__
-        self._add_natural_alteration(notations_table_entries)
-
-        # add glyphs for all remaining accidentals
         for accidental in self._ekmelily_accidentals:
             alteration_code = self._accidental_to_alteration_code_mapping[accidental]
             accidental_notation = "({} {})".format(
@@ -495,7 +452,6 @@ class EkmelilyTuningFileConverter(converters_abc.Converter):
     def convert(self):
         """Render tuning file to :attr:`path`."""
 
-        # TODO(Make docstring with example!)
         ekmelily_tuning_file = (
             self._make_tuning_table(),
             self._make_languages_table(),
@@ -515,31 +471,45 @@ class HEJIEkmelilyTuningFileConverter(EkmelilyTuningFileConverter):
     :param path: Path where the new Ekmelily tuning file shall be written.
         The suffix '.ily' is recommended, but not necessary.
     :type path: str
+    :param prime_to_highest_allowed_exponent: Mapping of prime number to
+        highest exponent that should occur. Take care not to add
+        higher exponents than the HEJI Notation supports. See
+        :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_PRIME_TO_HIGHEST_ALLOWED_EXPONENT`
+        for the default mapping.
+    :type prime_to_highest_allowed_exponent: typing.Dict[int, int], optional
     :param reference_pitch: The reference pitch (1/1). Should be a diatonic
-        pitch name (see :const:`~mutwo.parameters.pitches_constants.ASCENDING_DIATONIC_PITCH_NAMES`)
-        in English nomenclature. For any reference pitch != 'c' Lilyponds midi rendering
-        won't be correct.
+        pitch name (see
+        :const:`~mutwo.parameters.pitches_constants.ASCENDING_DIATONIC_PITCH_NAMES`)
+        in English nomenclature. For any other reference pitch than 'c', Lilyponds
+        midi rendering for pitches with the diatonic pitch 'c' will be slightly
+        out of tune (because the first value of :arg:`global_scale`
+        always have to be 0).
     :type reference_pitch: str, optional
     :param prime_to_heji_accidental_name: Mapping of a prime number
         to a string which indicates the respective prime number in the resulting
-        accidental name. See :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_PRIME_TO_HEJI_ACCIDENTAL_NAME`
+        accidental name. See
+        :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_PRIME_TO_HEJI_ACCIDENTAL_NAME`
         for the default mapping.
     :type prime_to_heji_accidental_name: typing.Dict[int, str], optional
     :param otonality_indicator: String which indicates that the
-        respective prime alteration is otonal. See :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_OTONALITY_INDICATOR`
+        respective prime alteration is otonal. See
+        :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_OTONALITY_INDICATOR`
         for the default value.
     :type otonality_indicator: str, optional
     :param utonality_indicator: String which indicates that the
-        respective prime alteration is utonal. See :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_OTONALITY_INDICATOR`
+        respective prime alteration is utonal. See
+        :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_OTONALITY_INDICATOR`
         for the default value.
     :type utonality_indicator: str, optional
     :param exponent_to_exponent_indicator: Function to convert the
         exponent of a prime number to string which indicates the respective
-        exponent. See :func:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_EXPONENT_TO_EXPONENT_INDICATOR`
+        exponent. See
+        :func:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_EXPONENT_TO_EXPONENT_INDICATOR`
         for the default function.
     :type exponent_to_exponent_indicator: typing.Callable[[int], str], optional
     :param tempered_pitch_indicator: String which indicates that the
-        respective accidental is tempered (12 EDO). See :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_TEMPERED_PITCH_INDICATOR`
+        respective accidental is tempered (12 EDO). See
+        :const:`~mutwo.converters.frontends.ekmelily_constants.DEFAULT_TEMPERED_PITCH_INDICATOR`
         for the default value.
     :type tempered_pitch_indicator: str, optional
     """
@@ -677,11 +647,10 @@ class HEJIEkmelilyTuningFileConverter(EkmelilyTuningFileConverter):
             cents_deviation = frontends.ekmelily_constants.PYTHAGOREAN_ACCIDENTAL_TO_CENT_DEVIATIONS[
                 alteration_name
             ]
-            if cents_deviation != 0:
-                accidental = EkmelilyAccidental(
-                    alteration_name, (glyph,), cents_deviation
-                )
-                accidentals.append(accidental)
+            accidental = EkmelilyAccidental(
+                alteration_name, (glyph,), cents_deviation
+            )
+            accidentals.append(accidental)
 
         return tuple(accidentals)
 
@@ -718,19 +687,16 @@ class HEJIEkmelilyTuningFileConverter(EkmelilyTuningFileConverter):
     @staticmethod
     def _make_higher_prime_accidental(
         pythagorean_accidental: str,
+        pythagorean_accidental_cents_deviation: float,
+        exponents: typing.Tuple[int, ...],
         prime_to_highest_allowed_exponent: typing.Dict[int, int],
         prime_to_heji_accidental_name: typing.Dict[int, str],
-        exponents: typing.Tuple[int, ...],
         otonality_indicator: str,
         utonality_indicator: str,
         exponent_to_exponent_indicator: typing.Callable[[int], str],
     ) -> EkmelilyAccidental:
         accidental_parts = ["{}".format(pythagorean_accidental)]
-        cents_deviation = float(
-            frontends.ekmelily_constants.PYTHAGOREAN_ACCIDENTAL_TO_CENT_DEVIATIONS[
-                pythagorean_accidental
-            ]
-        )
+        cents_deviation = float(pythagorean_accidental_cents_deviation)
         glyphs = []
         for prime, exponent in zip(
             prime_to_highest_allowed_exponent.keys(), exponents,
@@ -794,15 +760,17 @@ class HEJIEkmelilyTuningFileConverter(EkmelilyTuningFileConverter):
         for exponents in itertools.product(*allowed_exponents):
             if any(tuple(exp != 0 for exp in exponents)):
                 for (
-                    pythagorean_accidental
+                    pythagorean_accidental,
+                    pythagorean_accidental_cents_deviation,
                 ) in (
-                    frontends.ekmelily_constants.PYTHAGOREAN_ACCIDENTAL_TO_CENT_DEVIATIONS.keys()
+                    frontends.ekmelily_constants.PYTHAGOREAN_ACCIDENTAL_TO_CENT_DEVIATIONS.items()
                 ):
                     accidental = HEJIEkmelilyTuningFileConverter._make_higher_prime_accidental(
                         pythagorean_accidental,
+                        pythagorean_accidental_cents_deviation,
+                        exponents,
                         prime_to_highest_allowed_exponent,
                         prime_to_heji_accidental_name,
-                        exponents,
                         otonality_indicator,
                         utonality_indicator,
                         exponent_to_exponent_indicator,
@@ -842,8 +810,6 @@ class HEJIEkmelilyTuningFileConverter(EkmelilyTuningFileConverter):
                     ]
                     - difference_in_cents_from_tempered_pitch_class
                 )
-                if deviation_in_cents == 0:
-                    deviation_in_cents = 0.2
 
                 accidental = EkmelilyAccidental(
                     accidental_name,
@@ -868,12 +834,10 @@ class HEJIEkmelilyTuningFileConverter(EkmelilyTuningFileConverter):
         tempered_pitch_indicator: str,
     ) -> typing.Tuple[EkmelilyAccidental, ...]:
 
-        # standard flat / sharp
         pythagorean_accidentals = (
             HEJIEkmelilyTuningFileConverter._make_pythagorean_accidentals()
         )
 
-        # add accidentals with commas
         accidentals_for_higher_primes = HEJIEkmelilyTuningFileConverter._make_accidentals_for_higher_primes(
             prime_to_highest_allowed_exponent,
             prime_to_heji_accidental_name,
@@ -882,7 +846,6 @@ class HEJIEkmelilyTuningFileConverter(EkmelilyTuningFileConverter):
             exponent_to_exponent_indicator,
         )
 
-        # make tempered accidentals
         tempered_accidentals = HEJIEkmelilyTuningFileConverter._make_tempered_accidentals(
             difference_in_cents_from_tempered_pitch_class_for_diatonic_pitches,
             tempered_pitch_indicator,
